
// a simple driver for the simfold

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <time.h>

// include the simfold header files
#include "simfold.h"
#include "externs.h"
#include "constants.h"

int main (int argc, char *argv[])
{
    char sequence[MAXSLEN];
    char structure[MAXSLEN];
    char restricted[MAXSLEN];
    double energy;
    
    if (argc != 3 && argc != 4)
    {
        printf ("Usage: %s <sequence> <structure> [<restricted>]\n", argv[0]);
        return 0;
    }        
    strcpy (sequence, argv[1]);    
    strcpy (structure, argv[2]);
    if (argc == 4)
    {
        strcpy (restricted, argv[3]);
    }
    
    // Before calling any function in the library, you have to initialize config_file, dna_or_rna, temperature
    //     and to call the function init_data, which loads the thermodynamic parameters into memory
    
    // configuration file, the path should relative to the location of this executable
    char config_file[200] = "params/multirnafold.conf";

    // what to fold: RNA or DNA
    int dna_or_rna = RNA;

    // temperature: any integer or real number between 0 and 100
    // represents degrees Celsius
    double temperature = 37; 
    
    // initialize the thermodynamic parameters
    // call init_data only once for the same dna_or_rna and same temperature
    // if one of them changes, call init_data again   
    init_data (argv[0], config_file, dna_or_rna, temperature);         
    
    if (argc == 3)
    {
        energy = free_energy_simfold (sequence, structure);
    }    
    else
    {
        energy = free_energy_simfold_restricted (sequence, structure, restricted);
    }    
    printf ("%.2lf\n", energy);
    return 0;
}
    


