
// a simple driver for the pairfold

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <time.h>

// include the pairfold library
#include "pairfold.h"
#include "externs.h"
#include "timer.h"


int main (int argc, char *argv[])
{
    char sequence1[MAXSLEN], sequence2[MAXSLEN];
    char structure[2*MAXSLEN];
    double energy;
    int i, num_suboptimals;
    char structures[MAXSUBSTR][MAXSLEN];
    double energies[MAXSUBSTR];    
    timer stpw;
    //    double entropy, Tm, H, S;
    //    double target_conc1, target_conc2, salt_conc;
    //    int self_comp;    

    num_suboptimals = 1;
    
    if (argc != 3 && argc != 4)
    {
        printf ("Usage: %s <sequence1> <sequence2> [<number_suboptimals>]\n", argv[0]);
        return 0;
    }    
    strcpy (sequence1, argv[1]);
    strcpy (sequence2, argv[2]);
    if (argc == 4)
        num_suboptimals = atoi (argv[3]);
            
    // Before calling any function in the library, you have to initialize config_file, dna_or_rna, temperature
    //     and to call the function init_data, which loads the thermodynamic parameters into memory
    
    // configuration file, the path should relative to the location of this executable
    char config_file[200] = "params/multirnafold.conf";

    // what to fold: RNA or DNA
    int dna_or_rna = RNA;

    // temperature: any integer or real number between 0 and 100
    // represents degrees Celsius
    double temperature = 37; 
    
    // initialize the thermodynamic parameters
    // call init_data only once for the same dna_or_rna and same temperature
    // if one of them changes, call init_data again   
    init_data (argv[0], config_file, dna_or_rna, temperature);     
    
    if (num_suboptimals == 1)
    {
        stpw.reset();
        stpw.start();            
        energy = pairfold_mfe (sequence1, sequence2, structure);
        // You may want to check if the free energy of this structure was computed correctly
        //en2 = free_energy_pairfold (sequence1, sequence2, structure);
        stpw.stop();
        printf ("%s %s\n%s  %.2lf\t%.2lf\n", sequence1, sequence2, structure, energy, stpw.elapsed());                  
                
        // or you can call the function which doesn't allow intramolecular interactions
        //stpw.reset();
        //stpw.start();            
        //energy = pairfold_mfe_nointra (sequence1, sequence2, structure, 10);
        //stpw.stop();
        //printf ("%s %s\n%s  %.2lf\t%.2lf\n", sequence1, sequence2, structure, energy, stpw.elapsed());                          
        
    }
    else if (num_suboptimals > 1)
    {
        if (num_suboptimals > (MAXSUBSTR-2)/2)
        {
            printf ("Numer of suboptimals should be <= %d\n", (MAXSUBSTR-2)/2);
            printf ("If you need more, change the MAXSUBSTR constant in include/constants.h\n");
            exit(1);
        }
        printf ("%s %s\n", sequence1, sequence2);          
        pairfold_ordered_suboptimals (sequence1, sequence2, num_suboptimals, structures, energies);
        for (i=0; i < num_suboptimals; i++)
        {
            //en2 = free_energy_pairfold (sequence1, sequence2, structures[i]);
            printf ("%s  %.2lf\n", structures[i], energies[i]); 
        }
    }
    return 0;
}


 
